@@ -1,4 +1,4 @@
-use clap::Clap;
+use clap::Parser;
 
 pub use check::CheckArgs;
 pub use download::DownloadArgs;
@@ -14,9 +14,9 @@ mod logging;
 mod output;
 mod stream_filter;
 
-#[derive(Clap)]
+#[derive(Parser)]
 #[clap(
-version = "0.3.5",
+version = "0.3.6",
 about = "\n\
 A simple CLI for the rustube YouTube-downloader library.\n\
 For documentation and more information about rustube or the rustube-cli checkout \
@@ -54,7 +54,7 @@ pub enum Command {
     Fetch(FetchArgs),
 }
 
-#[derive(Clap)]
+#[derive(Parser)]
 pub struct Identifier {
     #[clap(about = "An arbitrary video identifier, like the videos URL or the video id")]
     identifier: String,
